@@ -7,4 +7,11 @@ import pytest  # pragma: no cover
 
 @pytest.fixture  # pragma: no cover
 def pytestbdd_feature_base_dir(request):
+    """Base feature directory."""
     return os.path.dirname(request.module.__file__)
+
+
+def pytest_addhooks(pluginmanager):
+    """Register plugin hooks."""
+    from pytest_bdd import hooks
+    pluginmanager.addhooks(hooks)
